@@ -30,6 +30,7 @@ def create_schematic(
     library_name,
     output_dir,
     component_id,
+    skip_existing
 ):
     class kicad_schematic:
         drawing = ""
@@ -124,13 +125,13 @@ def create_schematic(
         os.makedirs(f"{output_dir}/Schematic")
 
     if os.path.exists(filename):
-        update_library(library_name, ComponentName, template_lib_component, output_dir)
+        update_library(library_name, ComponentName, template_lib_component, output_dir, skip_existing)
     else:
         with open(filename, "w") as f:
             logging.info(f"writing in {filename} file")
             f.write(template_lib_header)
             f.write(template_lib_footer)
-        update_library(library_name, ComponentName, template_lib_component, output_dir)
+        update_library(library_name, ComponentName, template_lib_component, output_dir, skip_existing)
 
 
 def get_type_values_properties(start_index, component_types_values):
@@ -144,7 +145,7 @@ def get_type_values_properties(start_index, component_types_values):
     )
 
 
-def update_library(library_name, component_title, template_lib_component, output_dir):
+def update_library(library_name, component_title, template_lib_component, output_dir, skip_existing):
     """
     if component is already in library,
     the library will be updated,
@@ -153,10 +154,13 @@ def update_library(library_name, component_title, template_lib_component, output
     """
 
     with open(f"{output_dir}/Schematic/{library_name}.kicad_sym", "rb+") as lib_file:
-        pattern = f'  \(symbol "{component_title}" \(pin_names (\n|.)*?\n  \)'
+        pattern = f'  \(symbol "{component_title}" (\n|.)*?\n  \)'
         file_content = lib_file.read().decode()
 
-        if f'symbol "{component_title}" (pin_names' in file_content:
+        if f'symbol "{component_title}"' in file_content:
+            if skip_existing:
+                logging.info(f"component {component_title} already in schematics library, skipping")
+                return
             # use regex to find the old component template in the file and replace it with the new one
             logging.info(
                 f"found component already in {library_name}, updating {library_name}"
